@@ -55,6 +55,7 @@ OC.L10N.register(
     "Every year" : "Vuosittain",
     "never" : "ei koskaan",
     "after" : "jälkeen",
+    "Automatic ({timezone})" : "Automaattinen ({timezone})",
     "How about getting started by importing some calendars?" : "Haluaisitko tuoda kalentereita?",
     "At time of event" : "Tapahtuman aikaan",
     "5 minutes before" : "5 minuuttia ennen",
@@ -121,6 +122,7 @@ OC.L10N.register(
     "{calendar} shared by {owner}" : "{calendar} jakanut {owner}",
     "Please enter a valid WebCal-URL" : "Anna kelvollinen WebCal-osoite",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Kriittinen virhe webcal-välityspalvelimessa. Ota yhteyttä ylläpitäjään saadaksesi lisää tietoa.",
+    "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
     "Title of the Event" : "Tapahtuman otsikko",
     "Starts" : "Alkaa",
     "Ends" : "Päättyy",
@@ -190,6 +192,7 @@ OC.L10N.register(
     "The file contains objects incompatible with the selected calendar" : "Tiedosto sisältää valitun kalenterin kanssa yhteensopimattomia objekteja",
     "New calendar" : "Uusi kalenteri",
     "File is empty" : "Tiedosto on tyhjä",
+    "File could not be parsed" : "Tiedostoa ei voitu jäsentää",
     "Import scheduled" : "Tuonti ajastettu",
     "%s shared the calendar <strong>%s</strong> with you" : "%s jakoi kalenterin<strong>%s</strong>sinulle",
     "Embed" : "Upota",
@@ -200,8 +203,9 @@ OC.L10N.register(
     "No Calendars selected for import" : "Kalentereita ei ole valittu tuotavaksi",
     "Skip simple event editor" : "Ohita yksinkertainen tapahtumamuokkain",
     "Show week numbers" : "Näytä viikkonumerot",
+    "Timezone" : "Aikavyöhyke",
     "Primary CalDAV address" : "Ensisijainen CalDAV-osoite",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV -osoite",
+    "iOS/macOS CalDAV address" : "iOS/macOS:n CalDAV-osoite",
     "Subscribe" : "Tilaa"
 },
 "nplurals=2; plural=(n != 1);");
