@@ -10,7 +10,7 @@ OC.L10N.register(
     "Recipient" : "Címzett",
     "Too many redirects. Aborting ..." : "Túl sok átirányítás. Megszakítás...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "A távoli szerver nem adott hozzáférést a naptárhoz (HTTP hiba: {%s})",
-    "Error connecting to remote server" : "Hiba a távoli szerverhez való csatlahozásban",
+    "Error connecting to remote server" : "Hiba a távoli szerverhez való csatlakozásban",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Hiba a távoli szerver erőforrásainak lekérése közben. Lehetséges, hogy ez egy hibás tanúsítvány okozza.",
     "Error requesting resource on remote server" : "Hiba a távoli szerver erőforrásainak lekérése közben",
     "Individual" : "egyéni",
