@@ -29,8 +29,10 @@ OC.L10N.register(
     "Some events in this calendar are broken. Please check the JS console for more info." : "このカレンダーのいくつかのイベントは壊れています。 JSコンソールで詳細を確認してください。",
     "Share Calendar" : "カレンダーを共有する",
     "Shared" : "共有中",
+    "Could not save WebCal-calendar" : "WebCalカレンダーを保存できませんでした",
     "WebDAV address for subscriptions" : "サブスクリプションのWebDAVアドレス",
     "Email sent." : "メールを送信しました。",
+    "Could not send your email." : "あなたの電子メールを送信できませんでした。",
     "group" : "グループ",
     "Details" : "詳細",
     "Attendees" : "参加者",
@@ -53,6 +55,7 @@ OC.L10N.register(
     "Every year" : "毎年",
     "never" : "なし",
     "after" : "後",
+    "Automatic ({timezone})" : "自動 ({timezone})",
     "How about getting started by importing some calendars?" : "カレンダーをインポートして始めませんか？",
     "At time of event" : "イベント時",
     "5 minutes before" : "5分前",
@@ -75,19 +78,49 @@ OC.L10N.register(
     "end" : "終了",
     "Editing reminders of unknown type not supported." : "未知のタイプのリマインダの編集はサポートされていません。",
     "Week {number} of {year}" : "{year}の{number} 週",
+    "Successfully imported {imported} objects" : "{imported}オブジェクトを正常にインポートしました",
+    "Imported {imported} out of {all}, skipped one duplicate" : "{all} のうち {inported} されたものがインポートされました。",
+    "Imported {imported} out of {all}, one failure" : "{all} のうち {imported} インポートされたもの、1つの失敗",
+    "Imported {imported} out of {all}, {errors} failures" : "{all}、{errors}のうち{import}がインポートされました",
+    "Audio alarm {time} before the event starts" : "イベントが始まる前にオーディオアラーム {time}",
+    "Pop-up {time} before the event starts" : "イベント開始前に {time} ポップアップ",
+    "Email {time} before the event starts" : "イベントが開始される前に {time} までメールしてください",
+    "None {time} before the event starts" : "イベントが開始される前に {time} はありません",
     "{type} {time} before the event starts" : "イベント開始の{type} {time} 前",
+    "Audio alarm {time} before the event ends" : "イベントが終了する前にオーディオアラーム {time}",
+    "Pop-up {time} before the event ends" : "イベントが終了する前に {time} ポップアップ",
+    "Email {time} before the event ends" : "イベントが終了する前にメール {time}",
+    "None {time} before the event ends" : "イベントが終了する前に {time} はありません",
     "{type} {time} before the event ends" : "イベント終了の{type} {time} 前",
+    "Audio alarm {time} after the event starts" : "イベント開始後のオーディオアラーム {time}",
+    "Pop-up {time} after the event starts" : "イベント開始後のポップアップ {time}",
+    "Email {time} after the event starts" : "イベントが開始された後にメール {time}",
+    "None {time} after the event starts" : "イベント開始後は {time} なし",
     "{type} {time} after the event starts" : "イベント開始の{type} {time} 後",
+    "Audio alarm {time} after the event ends" : "イベント終了後のオーディオアラーム {time}",
+    "Pop-up {time} after the event ends" : "イベント終了後のポップアップ{time}",
+    "Email {time} after the event ends" : "イベントが終了した後にメール {time}",
+    "None {time} after the event ends" : "イベントが終了した後は {time} はありません",
     "{type} {time} after the event ends" : "イベント終了の{type} {time} 後",
+    "Audio alarm at the event's start" : "イベント開始時のオーディオアラーム",
+    "Pop-up at the event's start" : "イベント開始時のポップアップ",
     "Email at the event's start" : "イベント開始時にメールを送信する",
+    "None at the event's start" : "イベント開始時には何もありません",
     "{type} at the event's start" : "{type} イベント開始時",
+    "Audio alarm at the event's end" : "イベント終了時のオーディオアラーム",
+    "Pop-up at the event's end" : "イベント終了時のポップアップ",
     "Email at the event's end" : "イベント終了時にメールを送信する",
+    "None at the event's end" : "イベント終了時には何もありません",
     "{type} at the event's end" : "{type} イベント終了時",
+    "Audio alarm at {time}" : "{time} のオーディオアラーム",
+    "Pop-up at {time}" : "{time} のポップアップ",
     "Email at {time}" : "{time} にメールを送信",
+    "None at {time}" : "{time} には何もありません",
     "{type} at {time}" : "{type} {time} 時",
     "{calendar} shared by {owner}" : "{owner} が共有中の{calendar} ",
     "Please enter a valid WebCal-URL" : "有効なWebCal-URLを入力してください",
     "Severe error in webcal proxy. Please contact administrator for more information." : "webcalプロキシの重大なエラーです。 詳細については、管理者にお問い合わせください。",
+    "A Calendar app for Nextcloud" : "NextCloudのカレンダーアプリ",
     "Title of the Event" : "イベントのタイトル",
     "Starts" : "開始",
     "Ends" : "終了",
@@ -121,6 +154,7 @@ OC.L10N.register(
     "can edit" : "編集を許可",
     "Share link" : "URLで共有",
     "Public access" : "パブリックアクセス",
+    "Email link to person" : "電子メールリンク",
     "Send" : "送信",
     "New Calendar" : "新しいカレンダーを作成",
     "Name" : "名前",
@@ -138,6 +172,7 @@ OC.L10N.register(
     "Absolute" : "絶対指定",
     "Repeat" : "繰り返し",
     "times every" : "繰り返し",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "メールリマインダはまだCalDAVサーバーに実装されていないため、送信されません。",
     "Add" : "追加",
     "Email address of attendee" : "参加者のメールアドレス",
     "Please add your email address in the personal settings in order to add attendees." : "出席者に追加するにはアカウント設定でメールアドレスを追加してください",
@@ -155,6 +190,7 @@ OC.L10N.register(
     "The file contains objects incompatible with the selected calendar" : "指定したカレンダーに互換性のない情報がファイルに含まれています",
     "New calendar" : "新しいカレンダー",
     "File is empty" : "ファイルが空です",
+    "File could not be parsed" : "File could not be parsed",
     "Import scheduled" : "スケジュールのインポート",
     "%s shared the calendar <strong>%s</strong> with you" : "%sはカレンダー<strong>%s</strong>をあなたと共有しています。",
     "Embed" : "埋め込み",
@@ -165,7 +201,9 @@ OC.L10N.register(
     "No Calendars selected for import" : "インポートするカレンダーが指定されていません",
     "Skip simple event editor" : "シンプルイベントエディタをスキップ",
     "Show week numbers" : "週番号を表示する",
+    "Timezone" : "タイムゾーン",
     "Primary CalDAV address" : "一番目の CalDAV アドレス",
+    "iOS/macOS CalDAV address" : "iOS / macOS CalDAVアドレス",
     "Subscribe" : "購読"
 },
 "nplurals=1; plural=0;");
