@@ -8,7 +8,7 @@ OC.L10N.register(
     "Open »%s«" : "Otwórz »%s«",
     "Cheers!" : "Zdrówko!",
     "Recipient" : "Odbiorca",
-    "Too many redirects. Aborting ..." : "Za dużo przekierowań. Przerywam...",
+    "Too many redirects. Aborting ..." : "Za dużo przekierowań. Przerywam…",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Brak dostępu do kalendarza na zdalnym serwerze (HTTP {%s} error)",
     "Error connecting to remote server" : "Błąd podczas łączenia się z serwerem zdalnym",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Błąd żądania zasobu na zdalnym serwerze. Możliwe, że może to być związane z niedopasowaniem certyfikatu",
@@ -55,6 +55,7 @@ OC.L10N.register(
     "Every year" : "Co roku",
     "never" : "nigdy",
     "after" : "po",
+    "Automatic ({timezone})" : "Automatycznie ({timezone})",
     "How about getting started by importing some calendars?" : "Czy rozpocząć pracę przez importowanie kilku kalendarzy?",
     "At time of event" : "W momencie zdarzenia",
     "5 minutes before" : "5 minut przed",
@@ -121,13 +122,14 @@ OC.L10N.register(
     "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
     "Please enter a valid WebCal-URL" : "Wprowadź prawidłowy URL WebCal",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Poważny błąd proxy w WebCal. Aby uzyskać więcej informacji prosimy o kontakt z administratorem.",
+    "A Calendar app for Nextcloud" : "Aplikacja Kalendarz dla Nextcloud",
     "Title of the Event" : "Nazwa wydarzenia",
     "Starts" : "Zaczyna się",
     "Ends" : "Kończy się",
     "All day Event" : "Wydarzenie całodniowe",
     "Delete" : "Usuń",
     "Cancel" : "Anuluj",
-    "More ..." : "Więcej...",
+    "More ..." : "Więcej…",
     "Create" : "Utwórz",
     "Update" : "Aktualizuj",
     "Close" : "Zamknij",
@@ -181,8 +183,8 @@ OC.L10N.register(
     "This event's repeating rule is not supported yet." : "Ta reguła powtarzania wydarzenia nie jest jeszcze wspierana.",
     "Support for advanced rules will be added with subsequent updates." : "Wsparcie dla zaawansowanych zasad będzie wprowadzane sukcesywnie wraz z kolejnymi aktualizacjami.",
     "Reset repeating rule" : "Zresetuj powtarzającą się zasadę",
-    "Repeat every ..." : "Powtarzaj każdą...",
-    "end repeat ..." : "zakończ powtarzanie...",
+    "Repeat every ..." : "Powtarzaj każdą…",
+    "end repeat ..." : "zakończ powtarzanie…",
     "times" : "razy",
     "Import Calendars" : "Importuj kalendarze",
     "Import canceled" : "Import anulowany",
@@ -190,6 +192,7 @@ OC.L10N.register(
     "The file contains objects incompatible with the selected calendar" : "Plik zawiera obiekty niekompatybilne z wybranym kalendarzem",
     "New calendar" : "Nowy kalendarz",
     "File is empty" : "Plik jest pusty",
+    "File could not be parsed" : "Nie można przeanalizować pliku",
     "Import scheduled" : "Import został zaplanowany",
     "%s shared the calendar <strong>%s</strong> with you" : "%s udostępnił Tobie kalendarz <strong>%s</strong>",
     "Embed" : "Osadź",
@@ -200,8 +203,9 @@ OC.L10N.register(
     "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
     "Skip simple event editor" : "Pomiń prosty edytor zdarzeń",
     "Show week numbers" : "Pokaż numery tygodni",
+    "Timezone" : "Strefa czasowa",
     "Primary CalDAV address" : "Podstawowy adres CalDAV",
-    "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X",
+    "iOS/macOS CalDAV address" : "Adres CalDAV dla iOS/macOS",
     "Subscribe" : "Subskrybuj"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
