@@ -2,7 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Koledar",
-    "%s has published the calendar »%s«" : "%s je objavil koledar \"%s\"",
+    "%s has published the calendar »%s«" : "%s je objavil(a) koledar \"%s\"",
     "Hello," : "Živijo,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Želimo te obvestiti, da je %s objavil(a) koledar %s.",
     "Open »%s«" : "Odpri »%s«",
@@ -26,10 +26,12 @@ OC.L10N.register(
     "Please create a calendar first." : "Najprej je treba ustvariti koledar.",
     "New event" : "Nov dogodek",
     "CalDAV address for clients" : "CalDAV naslov za odjemalce",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Nekateri vpisani dogodki v koledarju so okvarjeni. Preverite konzolo JS za več podrobnosti.",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Nekateri vpisi v koledarju so napačni. Za več podrobnosti preverite konzolo JS.",
     "Share Calendar" : "Omogoči souporabo koledarja",
     "Shared" : "V souporabi",
     "WebDAV address for subscriptions" : "WebDAV naslov za naročnike",
+    "Email sent." : "Elektronsko sporočilo je poslano.",
+    "Could not send your email." : "Sporočila ni bilo mogoče poslati.",
     "group" : "skupina",
     "Details" : "Podrobnosti",
     "Attendees" : "Udeleženci",
@@ -137,7 +139,7 @@ OC.L10N.register(
     "times every" : "krat vsakih",
     "Add" : "Dodaj",
     "Email address of attendee" : "Elektronski naslov udeleženca",
-    "Please add your email address in the personal settings in order to add attendees." : "Dodati morate vaš elektronski naslov med osebne nastavitve, preden je mogoče dodajati udeležence",
+    "Please add your email address in the personal settings in order to add attendees." : "Preden je mogoče dodajati udeležence, je treba nastaviti elektronski naslov med osebnimi nastavitvami.",
     "from" : "od",
     "to" : "za",
     "This event's repeating rule is not supported yet." : "Ponavljajoče pravilo tega dogodka še ni podprto.",
@@ -146,7 +148,7 @@ OC.L10N.register(
     "Repeat every ..." : "Ponovi na ..",
     "end repeat ..." : "in ponovi ...",
     "times" : "krat",
-    "Import Calendars" : "Uvoz koledarjev",
+    "Import Calendars" : "Uvozi koledarje",
     "Import canceled" : "Uvoz je preklican",
     "Analyzing calendar" : "Preučevanje koledarja",
     "The file contains objects incompatible with the selected calendar" : "Datoteka vsebuje predmete, ki so neskladne z izbranim koledarjem",
@@ -158,11 +160,13 @@ OC.L10N.register(
     "Iframe to integrate" : "Iframe za integracijo",
     "Publish URL" : "Objavi URL",
     "Settings & import" : "Nastavitve in uvoz",
-    "Import calendar" : "Uvoz koledarja",
+    "Import calendar" : "Uvozi koledar",
     "No Calendars selected for import" : "Ni navedenih koledarjev za uvoz",
     "Skip simple event editor" : "Preskoči enostavni urejevalnik dogodkov",
     "Show week numbers" : "Pokaži številke tednov",
+    "Timezone" : "Časovni pas",
     "Primary CalDAV address" : "Osnovni naslov CalDAV",
+    "iOS/macOS CalDAV address" : "Naslov CalDAV za iOS/macOS",
     "Subscribe" : "Naročite se"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
