@@ -55,6 +55,7 @@ OC.L10N.register(
     "Every year" : "Varje år",
     "never" : "aldrig",
     "after" : "efter",
+    "Automatic ({timezone})" : "Automatisk ({timezone})",
     "How about getting started by importing some calendars?" : "Vad sägs om att komma igång genom att importera några kalendrar?",
     "At time of event" : "På tid för event",
     "5 minutes before" : "5 minuter före",
@@ -77,11 +78,24 @@ OC.L10N.register(
     "end" : "slut",
     "Editing reminders of unknown type not supported." : "Att redigera påminnelser för okända typer stöds inte.",
     "Week {number} of {year}" : "Vecka {number} år {year}",
+    "Successfully imported {imported} objects" : "Lyckades importera {imported} objekt",
+    "Imported {imported} out of {all}, skipped one duplicate" : "Importerade {imported} av {all}, skippade en dubblett",
     "Imported {imported} out of {all}, one failure" : "Importerade {imported} av {all}, en misslyckades",
+    "Imported {imported} out of {all}, {errors} failures" : "Importerade {imported} av {all}, {errors} misslyckades",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Importerade {imported} av {all}, skippade {duplicates} dubbletter",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Importerade {imported} av {all}, {errors} misslyckades, skippades {duplicates} dubbletter",
     "Audio alarm {time} before the event starts" : "Ljudalarm {time} före händelsen startar",
+    "Pop-up {time} before the event starts" : "Pop-up {time} innan händelsen startar",
     "Email {time} before the event starts" : "Epost {time} före händelsen startar",
+    "None {time} before the event starts" : "Ingen {time} innan händelsen startar",
     "{type} {time} before the event starts" : "{type} {time} före händelsen börjar",
+    "Audio alarm {time} before the event ends" : "Ljudlarm {time} innan händelsen slutar",
+    "Pop-up {time} before the event ends" : "Pop-up {time} innan händelsen slutar",
+    "Email {time} before the event ends" : "E-post {time} innan händelsen slutar",
+    "None {time} before the event ends" : "Ingen {time} innan händelsen slutar",
     "{type} {time} before the event ends" : "{type} {time} före händelsen slutar",
+    "Audio alarm {time} after the event starts" : "Ljudlarm {time} efter händelsen startar",
+    "Pop-up {time} after the event starts" : "Pop-up {time} efter händelsen startar",
     "Email {time} after the event starts" : "E-posta {time} efter händelsen startar",
     "None {time} after the event starts" : "Gör inget {time} efter händelsen startas",
     "{type} {time} after the event starts" : "{type} {time} efter händelsen börjar",
@@ -108,6 +122,7 @@ OC.L10N.register(
     "{calendar} shared by {owner}" : "{calendar} delad utav {owner}",
     "Please enter a valid WebCal-URL" : "Vänligen ange en giltig WebCal-URL",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Allvarligt fel i webcal proxy. Vänligen kontakta administratören för vidare information.",
+    "A Calendar app for Nextcloud" : "En kalender-app för Nextcloud",
     "Title of the Event" : "Rubrik för händelsen",
     "Starts" : "Börjar",
     "Ends" : "Slutar",
@@ -159,6 +174,7 @@ OC.L10N.register(
     "Absolute" : "Absolut",
     "Repeat" : "Upprepa",
     "times every" : "gånger varje",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "E-postpåminnelser har inte implementerats på CalDAV-servern ännu, så ingen kommer att skickas.",
     "Add" : "Lägg till",
     "Email address of attendee" : "E-post-adresser av deltagare",
     "Please add your email address in the personal settings in order to add attendees." : "Vänligen lägg till din e-postadress i personliga inställningar för att kunna lägga till deltagare.",
@@ -176,6 +192,7 @@ OC.L10N.register(
     "The file contains objects incompatible with the selected calendar" : "Filen innehåller objekt inkompatibla med den valda kalendern",
     "New calendar" : "Ny kalender",
     "File is empty" : "Filen är tom",
+    "File could not be parsed" : "Filen kunde inte läsas",
     "Import scheduled" : "Import schemalagd",
     "%s shared the calendar <strong>%s</strong> with you" : "%s delade kalender <strong>%s</strong> med dig",
     "Embed" : "Bädda in",
@@ -186,8 +203,9 @@ OC.L10N.register(
     "No Calendars selected for import" : "Ingen kalender vald för import",
     "Skip simple event editor" : "Använd inte den enkla händelse-redigeraren",
     "Show week numbers" : "Visa veckonummer",
+    "Timezone" : "Tidszon",
     "Primary CalDAV address" : "Primär CalDAV adress",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adress",
+    "iOS/macOS CalDAV address" : "iOS/macOS CalDAV adress",
     "Subscribe" : "Prenumerera"
 },
 "nplurals=2; plural=(n != 1);");
