@@ -22,9 +22,13 @@
  *
  */
 ?>
-<ul class="app-navigation-list calendar-list">
-	<div ng-class="{'icon-loading-small': is.loading}"></div>
-	<li ng-repeat="item in calendarListItems | orderBy: item.calendar.order | calendarListFilter" class="app-navigation-list-item" ng-class="{active: item.calendar.enabled}">
-		<?php print_unescaped($this->inc('part.calendarlist.item')); ?>
-	</li>
-</ul>
+<li ng-if="is.loading" class="icon-loading-small loader-list"><a></a></li>
+<li ng-repeat="item in calendarListItems | orderBy: item.calendar.order | calendarListFilter"
+	class="app-navigation-list-item"
+	ng-class="{
+		active: item.calendar.enabled,
+		'icon-loading-small': item.displaySpinner(),
+		editing: item.isEditing() || item.displayCalDAVUrl || item.displayWebCalUrl
+	}">
+	<?php print_unescaped($this->inc('part.calendarlist.item')); ?>
+</li>
